==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a trigger.
 * @property baseImageTrigger The trigger based on base image dependencies.
 * @property sourceTriggers The collection of triggers based on source code repository.
 * @property timerTriggers The collection of timer triggers.
 */
public data class TriggerPropertiesArgs(
    public val baseImageTrigger: Output<BaseImageTriggerArgs>? = null,
    public val sourceTriggers: Output<List<SourceTriggerArgs>>? = null,
    public val timerTriggers: Output<List<TimerTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder()
            .baseImageTrigger(baseImageTrigger?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sourceTriggers(
                sourceTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timerTriggers(
                timerTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TriggerPropertiesArgs].
 */
@PulumiTagMarker
public class TriggerPropertiesArgsBuilder internal constructor() {
    private var baseImageTrigger: Output<BaseImageTriggerArgs>? = null

    private var sourceTriggers: Output<List<SourceTriggerArgs>>? = null

    private var timerTriggers: Output<List<TimerTriggerArgs>>? = null

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("tcajsepqhuaxwtyv")
    public suspend fun baseImageTrigger(`value`: Output<BaseImageTriggerArgs>) {
        this.baseImageTrigger = value
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("ohvpgrwrrxlyyodm")
    public suspend fun sourceTriggers(`value`: Output<List<SourceTriggerArgs>>) {
        this.sourceTriggers = value
    }

    @JvmName("ewcofyhricqwmfqe")
    public suspend fun sourceTriggers(vararg values: Output<SourceTriggerArgs>) {
        this.sourceTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("tbxtkreccelfytwc")
    public suspend fun sourceTriggers(values: List<Output<SourceTriggerArgs>>) {
        this.sourceTriggers = Output.all(values)
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("kpkcfpgivfplonen")
    public suspend fun timerTriggers(`value`: Output<List<TimerTriggerArgs>>) {
        this.timerTriggers = value
    }

    @JvmName("nycsweeateefbdkd")
    public suspend fun timerTriggers(vararg values: Output<TimerTriggerArgs>) {
        this.timerTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("wxqydfhqabhlbfom")
    public suspend fun timerTriggers(values: List<Output<TimerTriggerArgs>>) {
        this.timerTriggers = Output.all(values)
    }

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("ycuntuvcdikqkgjp")
    public suspend fun baseImageTrigger(`value`: BaseImageTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseImageTrigger = mapped
    }

    /**
     * @param argument The trigger based on base image dependencies.
     */
    @JvmName("mqscexerjtwisvrn")
    public suspend fun baseImageTrigger(argument: suspend BaseImageTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = BaseImageTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseImageTrigger = mapped
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("gdoiharbnbeawyfr")
    public suspend fun sourceTriggers(`value`: List<SourceTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("mwjosirwpnkbtwgs")
    public suspend fun sourceTriggers(argument: List<suspend SourceTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("cnsvletgijcvdmte")
    public suspend fun sourceTriggers(vararg argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("rurwwmjxipjntxwp")
    public suspend fun sourceTriggers(argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("jjxgkvekjufbnjro")
    public suspend fun sourceTriggers(vararg values: SourceTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("ypmdrlpukredasmg")
    public suspend fun timerTriggers(`value`: List<TimerTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("andkgshwlcpbumon")
    public suspend fun timerTriggers(argument: List<suspend TimerTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("iwmpogdvfkuiujlm")
    public suspend fun timerTriggers(vararg argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("xgkvpfwtnxxctqxb")
    public suspend fun timerTriggers(argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TimerTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("othbgvjpujmjogsp")
    public suspend fun timerTriggers(vararg values: TimerTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    internal fun build(): TriggerPropertiesArgs = TriggerPropertiesArgs(
        baseImageTrigger = baseImageTrigger,
        sourceTriggers = sourceTriggers,
        timerTriggers = timerTriggers,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of a trigger.
 * @property baseImageTrigger The trigger based on base image dependencies.
 * @property sourceTriggers The collection of triggers based on source code repository.
 * @property timerTriggers The collection of timer triggers.
 */
public data class TriggerPropertiesArgs(
    public val baseImageTrigger: Output<BaseImageTriggerArgs>? = null,
    public val sourceTriggers: Output<List<SourceTriggerArgs>>? = null,
    public val timerTriggers: Output<List<TimerTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.TriggerPropertiesArgs.builder()
            .baseImageTrigger(baseImageTrigger?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .sourceTriggers(
                sourceTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .timerTriggers(
                timerTriggers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TriggerPropertiesArgs].
 */
@PulumiTagMarker
public class TriggerPropertiesArgsBuilder internal constructor() {
    private var baseImageTrigger: Output<BaseImageTriggerArgs>? = null

    private var sourceTriggers: Output<List<SourceTriggerArgs>>? = null

    private var timerTriggers: Output<List<TimerTriggerArgs>>? = null

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("ghtuthyqdvuhmifv")
    public suspend fun baseImageTrigger(`value`: Output<BaseImageTriggerArgs>) {
        this.baseImageTrigger = value
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("krtbfohitrhfivcc")
    public suspend fun sourceTriggers(`value`: Output<List<SourceTriggerArgs>>) {
        this.sourceTriggers = value
    }

    @JvmName("tvyipassircnfsup")
    public suspend fun sourceTriggers(vararg values: Output<SourceTriggerArgs>) {
        this.sourceTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("uwvfkebsdnwlyver")
    public suspend fun sourceTriggers(values: List<Output<SourceTriggerArgs>>) {
        this.sourceTriggers = Output.all(values)
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("vtylkslbtbpcuvxl")
    public suspend fun timerTriggers(`value`: Output<List<TimerTriggerArgs>>) {
        this.timerTriggers = value
    }

    @JvmName("cqqknbvyhqbrmjfw")
    public suspend fun timerTriggers(vararg values: Output<TimerTriggerArgs>) {
        this.timerTriggers = Output.all(values.asList())
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("yqofyuvrtmsjptst")
    public suspend fun timerTriggers(values: List<Output<TimerTriggerArgs>>) {
        this.timerTriggers = Output.all(values)
    }

    /**
     * @param value The trigger based on base image dependencies.
     */
    @JvmName("hyulndyeysjsxkmp")
    public suspend fun baseImageTrigger(`value`: BaseImageTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseImageTrigger = mapped
    }

    /**
     * @param argument The trigger based on base image dependencies.
     */
    @JvmName("fkymeavlrhyqinjw")
    public suspend fun baseImageTrigger(argument: suspend BaseImageTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = BaseImageTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.baseImageTrigger = mapped
    }

    /**
     * @param value The collection of triggers based on source code repository.
     */
    @JvmName("dvvxynjsxflcpfnm")
    public suspend fun sourceTriggers(`value`: List<SourceTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("lpxlitltgyoosqqo")
    public suspend fun sourceTriggers(argument: List<suspend SourceTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("ckanlnippkbtibqq")
    public suspend fun sourceTriggers(vararg argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SourceTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param argument The collection of triggers based on source code repository.
     */
    @JvmName("vwmgtpcxwohjwuld")
    public suspend fun sourceTriggers(argument: suspend SourceTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SourceTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sourceTriggers = mapped
    }

    /**
     * @param values The collection of triggers based on source code repository.
     */
    @JvmName("lnstohlohlooiysc")
    public suspend fun sourceTriggers(vararg values: SourceTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceTriggers = mapped
    }

    /**
     * @param value The collection of timer triggers.
     */
    @JvmName("aifltqwwckyqsaom")
    public suspend fun timerTriggers(`value`: List<TimerTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("yfakqnmyktlgwiip")
    public suspend fun timerTriggers(argument: List<suspend TimerTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("lupfgkeiprjkhyvh")
    public suspend fun timerTriggers(vararg argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TimerTriggerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param argument The collection of timer triggers.
     */
    @JvmName("coqeqpsqjqgigqmi")
    public suspend fun timerTriggers(argument: suspend TimerTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TimerTriggerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.timerTriggers = mapped
    }

    /**
     * @param values The collection of timer triggers.
     */
    @JvmName("qpayyyctgelbikyg")
    public suspend fun timerTriggers(vararg values: TimerTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timerTriggers = mapped
    }

    internal fun build(): TriggerPropertiesArgs = TriggerPropertiesArgs(
        baseImageTrigger = baseImageTrigger,
        sourceTriggers = sourceTriggers,
        timerTriggers = timerTriggers,
    )
}
